Stan Math Library: stan/math/fwd/scal/fun/trunc.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

trunc.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_TRUNC_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_TRUNC_HPP
3
4 #include <math.h>
5 #include <stan/math/fwd/core.hpp>
6
7
8 namespace stan {
9 namespace math {
10
11 template <typename T>
12 inline fvar<T> trunc(const fvar<T>& x) {
13 using ::trunc;
14 return fvar<T>(trunc(x.val_), 0);
15 }
16
17 }
18 }
19 #endif
stan::math::trunc
var trunc(const var &a)
Returns the truncatation of the specified variable (C99).
Definition: trunc.hpp:60
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::trunc
fvar< T > trunc(const fvar< T > &x)
Definition: trunc.hpp:12
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.